ete2.coretype.arraytable

Package ete2 :: Package coretype :: Module arraytable |
[hide private]
[frames] | no frames]

# Module arraytable

source code

Classes | [hide private]
| ArrayTable This object is thought to work with matrix datasets (like microarrays).

Functions | [hide private]
get_centroid_dist(vcenter, vlist, fdist) | source code
get_average_centroid_linkage_dist(vcenter1, vlist1, vcenter2, vlist2, fdist) | source code
safe_mean(values) Returns mean value discarding non finite values | source code
safe_mean_vector(vectors) Returns mean profile discarding non finite values | source code
get_mean_vector(vlist) | source code
get_median_vector(vlist) | source code
get_max_vector(vlist) | source code
get_min_vector(vlist) | source code

Variables | [hide private]
| __VERSION__ = ``'``ete2-2.0rev95``'``
| __package__ = ``'``ete2.coretype``'``